@@ -6,8 +6,8 @@ import requests
 
 def make_session(
         username: str,
-        port: str='',
-        location: str='us',
+        port: str = '',
+        location: str = 'us',
         headers=None
 ):
     """ scrapekit.ipburger.make_session
@@ -57,5 +57,5 @@ def make_session(
 
 
 __all__ = [
-    make_session
-]
\ No newline at end of file
+    'make_session'
+]
